from django.conf import settings

TORRENT_STREAM_ZONE_ID = settings.TORRENT_STREAM_ZONE_ID
TORRENT_STREAM_AFFILIATE_KEY = settings.TORRENT_STREAM_AFFILIATE_KEY

TORRENT_STREAM_PLAYER = {
    'width': '650px',
    'height': '342px',
}
TORRENT_STREAM_CACHE_PREFIX = 'torrent_stream_'

if hasattr(settings, 'TORRENT_STREAM_PLAYER'):
    TORRENT_STREAM_PLAYER.update(settings.TORRENT_STREAM_PLAYER)

if hasattr(settings, 'TORRENT_STREAM_CACHE_PREFIX'):
    TORRENT_STREAM_CACHE_PREFIX = settings.TORRENT_STREAM_CACHE_PREFIX



import hashlib

from django import template
from django.core.cache import cache

from ..settings import TORRENT_STREAM_PLAYER, TORRENT_STREAM_CACHE_PREFIX

register = template.Library()


def torrent_stream_player(torrent_file):
    """Common context for player/button templates
    """
    torrent_content_hash = ''
    if hasattr(torrent_file, 'read'):
        torrent_content = torrent_file.read()
        torrent_content_hash = hashlib.md5(torrent_content).hexdigest()
        cache.set(
            TORRENT_STREAM_CACHE_PREFIX + torrent_content_hash,
            {'content': torrent_content})
    return {
        'torrent_content_hash': torrent_content_hash,
        'TORRENT_STREAM_PLAYER': TORRENT_STREAM_PLAYER,
    }


def torrent_stream_button(*args):
    return torrent_stream_player(*args)


register.inclusion_tag('torrent_stream/player.html')(torrent_stream_player)
register.inclusion_tag('torrent_stream/button.html')(torrent_stream_button)



import urllib

from django.core.cache import cache
from django.http import HttpResponse

from torrent_stream import settings
from torrent_stream.helpers import get_content_id
from torrent_stream.exceptions import FailedResponse, ServerFault


def torrent_stream_js(request, torrent_content_hash):
    cache_key = settings.TORRENT_STREAM_CACHE_PREFIX + torrent_content_hash
    torrent_stream = cache.get(cache_key)
    content_id = torrent_stream.get('content_id', None)
    if not content_id:
        torrent_content = torrent_stream.get('content', None)
        if torrent_content:
            try:
                torrent_stream['content_id'] = get_content_id(torrent_content)
                cache.set(cache_key, torrent_stream)
            except (FailedResponse, ServerFault):
                pass
    url = 'http://torrentstream.net/p/{0}'.format(torrent_stream['content_id'])
    return HttpResponse(urllib.urlopen(url).read(), content_type='text/javascript')
